@@ -21,6 +21,7 @@ import uuid
 from cdpcli import credentials, DEFAULT_PROFILE_NAME
 from cdpcli import xform_name
 from cdpcli.auth import AccessTokenAuth
+from cdpcli.auth import ECDSAv1Auth
 from cdpcli.auth import Ed25519v1Auth
 from cdpcli.auth import RSAv1Auth
 from cdpcli.cdprequest import prepare_request_dict
@@ -121,6 +122,8 @@ class ClientCreator(object):
             auth_method = AccessTokenAuth.AUTH_METHOD_NAME
         elif Ed25519v1Auth.detect_private_key(credentials.private_key):
             auth_method = Ed25519v1Auth.AUTH_METHOD_NAME
+        elif ECDSAv1Auth.detect_private_key(credentials.private_key):
+            auth_method = ECDSAv1Auth.AUTH_METHOD_NAME
         else:
             auth_method = RSAv1Auth.AUTH_METHOD_NAME
         additional_headers = dict()
@@ -323,6 +326,7 @@ class Context(object):
         # This is the shared credentials file.
         'credentials_file': (None, 'CDP_SHARED_CREDENTIALS_FILE',
                              '~/.cdp/credentials', None),
+        'cdp_region': ('cdp_region', None, None, None),
         'cdp_endpoint_url': ('cdp_endpoint_url', None, None, None),
         'endpoint_url': ('endpoint_url', None, None, None),
         'form_factor': ('form_factor', None, None, None),
